//xfile.cpp
#include <d3d9.h>
#include <d3dx9.h>


#include "../dx_base/graphics.h"
#include "xfile.h"

CXFile::CXFile()
{
	m_pMesh = NULL;
	m_pDevice = NULL;
}
//-------------------------------------------------------------------------------
CXFile::~CXFile()
{
	Release();
}
//-------------------------------------------------------------------------------
bool CXFile::Load(IDirect3DDevice9* pDevice, char* szFileName)
{
	HRESULT hr = 0;

	ID3DXBuffer* adjBuffer  = 0;
	ID3DXBuffer* matBuffer = 0;
	DWORD        numMtrls   = 0;

	hr = D3DXLoadMeshFromX(szFileName, D3DXMESH_MANAGED, pDevice, &adjBuffer, &matBuffer, 0, &numMtrls, &m_pMesh);
	if(FAILED(hr))
		return false;

	if( matBuffer != 0 && numMtrls != 0 )
	{
		D3DXMATERIAL* mat = (D3DXMATERIAL*)matBuffer->GetBufferPointer();

		for(int i = 0; i < (int)numMtrls; i++)
		{
			//MatD3D Ӽ ambient   Ƿ  ̸ Ѵ.
			mat[i].MatD3D.Ambient = mat[i].MatD3D.Diffuse;
			m_materialContainer.push_back( mat[i].MatD3D );

			if( mat[i].pTextureFilename != 0 )
			{
				IDirect3DTexture9* tex = 0;
				D3DXCreateTextureFromFile(pDevice, mat[i].pTextureFilename, &tex);

				m_textureContainer.push_back( tex );
			}
			else
				m_textureContainer.push_back( 0 );
		}
	}

	SAFE_RELEASE(matBuffer); 

	// Optimize the mesh.
	hr = m_pMesh->OptimizeInplace(D3DXMESHOPT_ATTRSORT | D3DXMESHOPT_COMPACT | D3DXMESHOPT_VERTEXCACHE,
		(DWORD*)adjBuffer->GetBufferPointer(), 0, 0, 0);

	SAFE_RELEASE(adjBuffer); 

	if(FAILED(hr))
		return false;

	m_pDevice = pDevice;
	return true;
}
//-------------------------------------------------------------------------------
void CXFile::Draw()
{
	for(int i = 0; i < (int)m_materialContainer.size(); i++)
	{
		m_pDevice->SetMaterial( &m_materialContainer[i] );
		m_pDevice->SetTexture(0, m_textureContainer[i]);
		m_pMesh->DrawSubset(i);
	}	
}
//-------------------------------------------------------------------------------
void CXFile::Release()
{
	if(m_pMesh)
	{
		SAFE_RELEASE(m_pMesh);

		for(int i = 0; i < (int)m_textureContainer.size(); i++)
			SAFE_RELEASE( m_textureContainer[i] );

		m_materialContainer.clear();
		m_textureContainer.clear();
	}
}