//testapp.cpp
#include <windows.h>
#include "./dx_base/graphics.h"
#include "testapp.h"
#include "./dx_util/xfile.h"


int APIENTRY WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow)
{
	CTestApp * pApp = new CTestApp;

	pApp->m_mainParam.hInstance = hInstance;
	pApp->m_mainParam.lpCmdLine = lpCmdLine;
	pApp->m_mainParam.nCmdShow = nCmdShow;
	
	pApp->Register(pApp, "XFile draw", 640, 480); 
	pApp->Run();
	pApp->Release();
	return 0;
}
//---------------------------------------------------------------------------------
CTestApp::CTestApp()
{
	m_pXFile = NULL;
	m_cameraRef.wheel = 0.0f;
}
//---------------------------------------------------------------------------------
CTestApp::~CTestApp()
{

}
//---------------------------------------------------------------------------------
void CTestApp::InitDirectionalLight()
{
	IDirect3DDevice9 * pDevice = m_pGraphics->GetDevice();

	D3DLIGHT9 light;
	ZeroMemory( &light, sizeof(light) );
	light.Type = D3DLIGHT_DIRECTIONAL;

	D3DXVECTOR3 vecDir;
	vecDir = D3DXVECTOR3(1.0f, -1.0f, 0.0f);
	D3DXVec3Normalize((D3DXVECTOR3*)&light.Direction, &vecDir );

	// set directional light diffuse color
	light.Type  = D3DLIGHT_DIRECTIONAL;
	light.Diffuse = D3DXCOLOR( 1.f, 1.f, 1.f, 1.f );
	light.Ambient = D3DXCOLOR( 0.f, 0.f, 0.f, 1.f );

	pDevice->SetLight( 0, &light );
	pDevice->LightEnable( 0, TRUE );
	pDevice->SetRenderState( D3DRS_LIGHTING, TRUE );
	pDevice->SetRenderState( D3DRS_ZENABLE,  TRUE );
	//Ambient Light 
	pDevice->SetRenderState(D3DRS_AMBIENT, 0x00202020);
}
//---------------------------------------------------------------------------------
bool CTestApp::PostGraphics()
{
	InitDirectionalLight();

	IDirect3DDevice9 * pDevice = m_pGraphics->GetDevice();
	
	m_pXFile = new CXFile;
	m_pXFile->Load(pDevice, "airplane 2.x");
	return true;
}
//---------------------------------------------------------------------------------
void CTestApp::Cleanup()
{
	SAFE_DELETE(m_pXFile);
	CApplication::Cleanup();
}
//---------------------------------------------------------------------------------
void CTestApp::Update()
{
}
//---------------------------------------------------------------------------------
void CTestApp::Render()
{
	D3DXMATRIX   matTranslation, matRot, matWorld;
	D3DXMatrixTranslation( &matTranslation, 0.0f, 0.0f, m_cameraRef.wheel * 2.0f);
	D3DXMatrixRotationYawPitchRoll( &matRot, D3DXToRadian(m_cameraRef.fRotateX), D3DXToRadian(m_cameraRef.fRotateY), 0.0f );
	IDirect3DDevice9 * pDevice = m_pGraphics->GetDevice();

	matWorld = matRot * matTranslation;
	pDevice->SetTransform( D3DTS_WORLD, &matWorld);

	m_pXFile->Draw();
}
//---------------------------------------------------------------------------------
bool CTestApp::ProcessKey(HWND hWnd, WPARAM wKey)
{
	return CApplication::ProcessKey(hWnd, wKey);
}


